@@ -179,6 +179,8 @@ class TonCrypto(TonModule):
     @Response.generate_random_bytes
     def generate_random_bytes(self, length: int) -> str:
         """
+        Generates random byte array of the specified length and returns
+        it in base64 format
         :param length: Size of random byte array
         :return: Base64 encoded generated bytes
         """
@@ -318,6 +320,7 @@ class TonCrypto(TonModule):
     @Response.nacl_box_keypair_from_secret_key
     def nacl_box_keypair_from_secret_key(self, secret: str) -> KeyPair:
         """
+        Generates key pair from a secret key
         :param secret: Hex encoded secret key
         :return:
         """
@@ -330,6 +333,7 @@ class TonCrypto(TonModule):
             self, decrypted: Union[str, bytes], nonce: str, their_public: str,
             secret: str) -> str:
         """
+        Public key authenticated encryption
         :param decrypted: Base64 encoded data to be encrypted
         :param nonce:
         :param their_public:
@@ -347,6 +351,8 @@ class TonCrypto(TonModule):
             self, encrypted: Union[str, bytes], nonce: str, their_public: str,
             secret: str) -> str:
         """
+        Decrypt and verify the cipher text using the receiver's secret key
+        and sender's public
         :param encrypted: Base64 encoded encrypted data to be decrypted
         :param nonce:
         :param their_public:
@@ -363,6 +369,7 @@ class TonCrypto(TonModule):
     def nacl_secret_box(
             self, decrypted: Union[str, bytes], nonce: str, key: str) -> str:
         """
+        Encrypt and authenticate message using nonce and secret key
         :param decrypted: Base64 encoded data to be encrypted
         :param nonce:
         :param key:
@@ -378,6 +385,7 @@ class TonCrypto(TonModule):
     def nacl_secret_box_open(
             self, encrypted: Union[str, bytes], nonce: str, key: str) -> str:
         """
+        Decrypts and verifies cipher text using nonce and secret key
         :param encrypted: Base64 encoded encrypted data to be decrypted
         :param nonce:
         :param key:
