@@ -15,6 +15,10 @@ class TestTonClientAsyncCore(unittest.TestCase):
         reference = self.client.get_api_reference()
         self.assertEqual(LIB_VERSION, reference['version'])
 
+    def test_build_info(self):
+        info = self.client.build_info()
+        self.assertIsInstance(info, dict)
+
     def test_destroy_context(self):
         self.client.destroy_context()
 
@@ -32,5 +36,9 @@ class TestTonClientSyncCore(unittest.TestCase):
         reference = self.client.get_api_reference()
         self.assertEqual(LIB_VERSION, reference['version'])
 
+    def test_build_info(self):
+        info = self.client.build_info()
+        self.assertIsInstance(info, dict)
+
     def test_destroy_context(self):
         self.client.destroy_context()
